Learn R Programming

geoidep (version 0.3.0)

get_sernanp_data: Download the available data from Sernanp

Description

This function allows you to download the latest version of data available on the sernanp geoviewer. For more information, you can visit the following web page: https://geo.sernanp.gob.pe/visorsernanp/

Usage

get_sernanp_data(layer = NULL, dsn = NULL, show_progress = TRUE, quiet = FALSE)

Value

An sf object.

Arguments

layer

Select only one from the list of available layers, for more information please use `get_data_sources(provider = "sernanp")`. Defaults to NULL.

dsn

Character. Output filename with the spatial format. If missing, a temporary file is created.

show_progress

Logical. Suppress bar progress.

quiet

Logical. Suppress info message.

Examples

Run this code
# \donttest{
library(geoidep)
library(sf)
anp <- get_sernanp_data(layer = "zonificacion_anp" , show_progress = FALSE)
plot(st_geometry(anp))
# }

Run the code above in your browser using DataLab