Learn R Programming

geoidep (version 0.3.0)

get_departaments: Download INEI departmental boundaries

Description

This function allows you to download the latest version of the geometry and ubigeos corresponding to the official political division of the departament boundaries of Peru. For more information, you can visit the following page https://ide.inei.gob.pe/

Usage

get_departaments(dsn = NULL, show_progress = TRUE, quiet = TRUE)

Value

An sf or tibble object.

Arguments

dsn

Character. Output filename. If missing, a temporary file is created.

show_progress

Logical. Suppress bar progress.

quiet

Logical. Suppress info message.

Examples

Run this code
# \donttest{
library(geoidep)
dep <- get_departaments(show_progress = FALSE)
head(dep)
# }

Run the code above in your browser using DataLab