Learn R Programming

geoidep (version 0.3.0)

get_districts: Download INEI district boundaries

Description

This function allows you to download the latest version of the geometry and ubigeos corresponding to the official political division of the district boundaries of Peru. For more information, you can visit the following page https://ide.inei.gob.pe/

Usage

get_districts(dsn = NULL, show_progress = TRUE, quiet = TRUE)

Value

An sf object.

Arguments

dsn

Character. Output filename with the *.gpkg format. If missing, a temporary file is created.

show_progress

Logical. Suppress bar progress.

quiet

Logical. Suppress info message.

Examples

Run this code
# \donttest{
library(geoidep)
dist <- get_districts(show_progress = FALSE)
head(dist)
# }

Run the code above in your browser using DataLab