Learn R Programming

geoidep (version 0.3.0)

get_early_warning: Download information on the latest deforestation alerts detected by Geobosque

Description

This function allows you to download deforestation alert information detected by Geobosque for any polygon located in Peru. For more details, please visit the following website: https://geobosques.minam.gob.pe

Usage

get_early_warning(region, sf = TRUE, show_progress = TRUE)

Value

A tibble or sf object, depending on the value of `sf`.

Arguments

region

A string Specifies the unique geographical code of interest.

sf

Logical. Indicates whether to return the data as an `sf` object.

show_progress

Logical. If TRUE, shows a progress bar during download.

Examples

Run this code
# \donttest{
library(geoidep)
amazonas <- get_departaments(show_progress = FALSE) |> subset(NOMBDEP == "AMAZONAS")
warning_point <- get_early_warning(region = amazonas, sf = TRUE, show_progress = FALSE)
head(warning_point)
# }

Run the code above in your browser using DataLab