powered by
This function allows you to download the latest version of the geometry and ubigeos corresponding to the official political division of the province boundaries of Peru. For more information, you can visit the following page https://ide.inei.gob.pe/
get_provinces(dsn = NULL, show_progress = TRUE, quiet = TRUE)
An sf or tibble object.
Character. Output filename. If missing, a temporary file is created.
Logical. Suppress bar progress.
Logical. Suppress info message.
# \donttest{ library(geoidep) prov <- get_provinces(show_progress = FALSE) head(prov) # }
Run the code above in your browser using DataLab