global-variables: Global variables for get_early_warning
This code declares global variables used in the `get_early_warning` function to avoid R CMD check warnings.
Description
Global variables for get_early_warning
This code declares global variables used in the `get_early_warning` function to avoid R CMD check warnings.